@@ -5,7 +5,6 @@ class GeneratorTypes(Enum):
     CONDA = "conda"
     REQUIREMENTS = "requirements"
     NONE = "none"
-    BOTH = "both"
 
     def __str__(self):
         return self.value
@@ -26,7 +25,3 @@ default_channels = [
 default_conda_dir = "conda/environments"
 default_requirements_dir = "python"
 default_dependency_file_path = "dependencies.yaml"
-
-
-def arch_cuda_key_fmt(arch, cuda_version):
-    return f"{arch}-{cuda_version}"
